=== modified file '__init__.py'
--- __init__.py	2007-02-03 16:04:46 +0000
+++ __init__.py	2007-02-17 09:02:59 +0000
@@ -56,13 +56,19 @@
 if __name__ != 'bzrlib.plugins.gtk':
     warning("Not running as bzrlib.plugins.gtk, things may break.")
 
-from bzrlib import errors
+from bzrlib.lazy_import import lazy_import
+lazy_import(globals(), """
+from bzrlib import (
+    branch,
+    errors,
+    workingtree,
+    )
+""")
+
 from bzrlib.commands import Command, register_command, display_command
 from bzrlib.errors import NotVersionedError, BzrCommandError, NoSuchFile
 from bzrlib.commands import Command, register_command
 from bzrlib.option import Option
-from bzrlib.branch import Branch
-from bzrlib.workingtree import WorkingTree
 from bzrlib.bzrdir import BzrDir
 
 import os.path
@@ -130,10 +136,10 @@
     
     """
     takes_args = [ "location?" ]
-    
+
     def run(self, location="."):
-        (branch, path) = Branch.open_containing(location)
-        
+        (br, path) = branch.Branch.open_containing(location)
+
         pygtk = import_pygtk()
         try:
             import gtk
@@ -144,7 +150,7 @@
         from push import PushDialog
 
         set_ui_factory()
-        dialog = PushDialog(branch)
+        dialog = PushDialog(br)
         dialog.run()
 
 register_command(cmd_gpush)
@@ -160,7 +166,7 @@
     @display_command
     def run(self, revision=None, filename=None):
         set_ui_factory()
-        wt = WorkingTree.open_containing(".")[0]
+        wt = workingtree.WorkingTree.open_containing(".")[0]
         branch = wt.branch
         if revision is not None:
             if len(revision) == 1:
@@ -215,28 +221,28 @@
 
     def run(self, location=".", revision=None, limit=None):
         set_ui_factory()
-        (branch, path) = Branch.open_containing(location)
-        branch.lock_read()
-        branch.repository.lock_read()
+        (br, path) = branch.Branch.open_containing(location)
+        br.lock_read()
+        br.repository.lock_read()
         try:
             if revision is None:
-                revid = branch.last_revision()
+                revid = br.last_revision()
                 if revid is None:
                     return
             else:
-                (revno, revid) = revision[0].in_history(branch)
+                (revno, revid) = revision[0].in_history(br)
 
             from viz.branchwin import BranchWindow
             import gtk
                 
             pp = BranchWindow()
-            pp.set_branch(branch, revid, limit)
+            pp.set_branch(br, revid, limit)
             pp.connect("destroy", lambda w: gtk.main_quit())
             pp.show()
             gtk.main()
         finally:
-            branch.repository.unlock()
-            branch.unlock()
+            br.repository.unlock()
+            br.unlock()
 
 
 register_command(cmd_visualise)
@@ -277,11 +283,11 @@
         from annotate.config import GAnnotateConfig
 
         try:
-            (tree, path) = WorkingTree.open_containing(filename)
-            branch = tree.branch
+            (tree, path) = workingtree.WorkingTree.open_containing(filename)
+            br = tree.branch
         except errors.NoWorkingTree:
-            (branch, path) = Branch.open_containing(filename)
-            tree = branch.basis_tree()
+            (br, path) = branch.Branch.open_containing(filename)
+            tree = br.basis_tree()
 
         file_id = tree.path2id(path)
 
@@ -290,8 +296,8 @@
         if revision is not None:
             if len(revision) != 1:
                 raise BzrCommandError("Only 1 revion may be specified.")
-            revision_id = revision[0].in_history(branch).rev_id
-            tree = branch.repository.revision_tree(revision_id)
+            revision_id = revision[0].in_history(br).rev_id
+            tree = br.repository.revision_tree(revision_id)
         else:
             revision_id = getattr(tree, 'get_revision_id', lambda: None)()
 
@@ -300,11 +306,11 @@
         window.set_title(path + " - gannotate")
         config = GAnnotateConfig(window)
         window.show()
-        branch.lock_read()
+        br.lock_read()
         try:
-            window.annotate(tree, branch, file_id)
+            window.annotate(tree, br, file_id)
         finally:
-            branch.unlock()
+            br.unlock()
         window.jump_to_line(line)
         
         gtk.main()
@@ -341,21 +347,21 @@
                                    StrictCommitFailed)
 
         wt = None
-        branch = None
+        br = None
         try:
-            (wt, path) = WorkingTree.open_containing(filename)
-            branch = wt.branch
+            (wt, path) = workingtree.WorkingTree.open_containing(filename)
+            br = wt.branch
         except NotBranchError, e:
             path = e.path
         except NoWorkingTree, e:
             path = e.base
             try:
-                (branch, path) = Branch.open_containing(path)
+                (br, path) = branch.Branch.open_containing(path)
             except NotBranchError, e:
                 path = e.path
 
 
-        commit = CommitDialog(wt, path, not branch)
+        commit = CommitDialog(wt, path, not br)
         commit.run()
 
 register_command(cmd_gcommit)
@@ -382,13 +388,34 @@
 
         set_ui_factory()
         from status import StatusDialog
-        (wt, wt_path) = WorkingTree.open_containing(path)
+        (wt, wt_path) = workingtree.WorkingTree.open_containing(path)
         status = StatusDialog(wt, wt_path)
         status.connect("destroy", gtk.main_quit)
         status.run()
 
 register_command(cmd_gstatus)
 
+class cmd_gconflicts(Command):
+    """ GTK+ push.
+    
+    """
+    def run(self):
+        (wt, path) = workingtree.WorkingTree.open_containing('.')
+        
+        pygtk = import_pygtk()
+        try:
+            import gtk
+        except RuntimeError, e:
+            if str(e) == "could not open display":
+                raise NoDisplayError
+
+        from bzrlib.plugins.gtk.conflicts import ConflictsDialog
+
+        set_ui_factory()
+        dialog = ConflictsDialog(wt)
+        dialog.run()
+
+register_command(cmd_gconflicts)
 
 import gettext
 gettext.install('olive-gtk')

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2007-02-03 14:17:40 +0000
+++ annotate/gannotate.py	2007-02-15 19:07:43 +0000
@@ -139,6 +139,7 @@
         current_revision.timestamp = time.time()
         current_revision.message = '[Not yet committed]'
         current_revision.parent_ids = tree.get_parent_ids()
+        current_revision.properties['branch-nick'] = self.branch.nick
         current_revno = '%d?' % (self.branch.revno() + 1)
         repository = self.branch.repository
         if self.revision_id == CURRENT_REVISION:
@@ -369,14 +370,14 @@
     For when a revision is referenced but not present.
     """
 
-    def __init__(self, revision_id, committer='?'):
+    def __init__(self, revision_id, committer='?', nick=None):
         self.revision_id = revision_id
         self.parent_ids = []
         self.committer = committer
         self.message = "?"
         self.timestamp = 0.0
         self.timezone = 0
-        self.properties = []
+        self.properties = {}
 
 
 class RevisionCache(object):

=== modified file 'commit.py'
--- commit.py	2007-02-03 17:00:25 +0000
+++ commit.py	2007-03-06 13:48:35 +0000
@@ -119,6 +119,7 @@
         self._textview_message.modify_font(pango.FontDescription("Monospace"))
         self.set_default_size(500, 500)
         self._vpaned_main.set_position(200)
+        self._button_commit.set_flags(gtk.CAN_DEFAULT)
 
         if self._is_pending:
             self._scrolledwindow_merges.set_policy(gtk.POLICY_AUTOMATIC,
@@ -170,6 +171,9 @@
         
         # Display dialog
         self.vbox.show_all()
+        
+        # Default to Commit button
+        self._button_commit.grab_default()
     
     def _on_treeview_files_row_activated(self, treeview, path, view_column):
         # FIXME: the diff window freezes for some reason
@@ -182,6 +186,8 @@
             _selected = model.get_value(iter, 1)
             
             diff = DiffWindow()
+            diff.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
+            diff.set_modal(True)
             parent_tree = self.wt.branch.repository.revision_tree(self.wt.branch.last_revision())
             diff.set_diff(self.wt.branch.nick, self.wt, parent_tree)
             try:

=== added file 'conflicts.py'
--- conflicts.py	1970-01-01 00:00:00 +0000
+++ conflicts.py	2007-02-03 17:19:29 +0000
@@ -0,0 +1,173 @@
+# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+try:
+    import pygtk
+    pygtk.require("2.0")
+except:
+    pass
+
+import os
+
+import gtk
+import gobject
+
+from bzrlib.config import GlobalConfig
+
+from dialog import error_dialog, warning_dialog
+from errors import show_bzr_error
+
+class ConflictsDialog(gtk.Dialog):
+    """ This dialog displays the list of conflicts. """
+    def __init__(self, wt, parent=None):
+        """ Initialize the Conflicts dialog. """
+        gtk.Dialog.__init__(self, title="Conflicts - Olive",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CANCEL))
+        
+        # Get arguments
+        self.wt = wt
+        
+        # Create the widgets
+        self._scrolledwindow = gtk.ScrolledWindow()
+        self._treeview = gtk.TreeView()
+        self._label_diff3 = gtk.Label(_("External utility:"))
+        self._entry_diff3 = gtk.Entry()
+        self._image_diff3 = gtk.Image()
+        self._button_diff3 = gtk.Button()
+        self._hbox_diff3 = gtk.HBox()
+        
+        # Set callbacks
+        self._button_diff3.connect('clicked', self._on_diff3_clicked)
+        
+        # Set properties
+        self._scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC,
+                                        gtk.POLICY_AUTOMATIC)
+        self._image_diff3.set_from_stock(gtk.STOCK_APPLY, gtk.ICON_SIZE_BUTTON)
+        self._button_diff3.set_image(self._image_diff3)
+        self._entry_diff3.set_text(self._get_diff3())
+        self._hbox_diff3.set_spacing(3)
+        self.vbox.set_spacing(3)
+        self.set_default_size(400, 300)
+        
+        # Construct dialog
+        self._hbox_diff3.pack_start(self._label_diff3, False, False)
+        self._hbox_diff3.pack_start(self._entry_diff3, True, True)
+        self._hbox_diff3.pack_start(self._button_diff3, False, False)
+        self._scrolledwindow.add(self._treeview)
+        self.vbox.pack_start(self._scrolledwindow, True, True)
+        self.vbox.pack_start(self._hbox_diff3, False, False)
+        
+        # Create the conflict list
+        self._create_conflicts()
+        
+        # Show the dialog
+        self.vbox.show_all()
+    
+    def _get_diff3(self):
+        """ Get the specified diff3 utility. Default is meld. """
+        config = GlobalConfig()
+        diff3 = config.get_user_option('gconflicts_diff3')
+        if diff3 is None:
+            diff3 = 'meld'
+        return diff3
+    
+    def _set_diff3(self, cmd):
+        """ Set the default diff3 utility to cmd. """
+        config = GlobalConfig()
+        config.set_user_option('gconflicts_diff3', cmd)
+    
+    def _create_conflicts(self):
+        """ Construct the list of conflicts. """
+        if len(self.wt.conflicts()) == 0:
+            self.model = gtk.ListStore(gobject.TYPE_STRING)
+            self._treeview.set_model(self.model)
+            self._treeview.append_column(gtk.TreeViewColumn(_('Conflicts'),
+                                         gtk.CellRendererText(), text=0))
+            self._treeview.set_headers_visible(False)            
+            self.model.append([ _("No conflicts in working tree.") ])
+        else:
+            self.model = gtk.ListStore(gobject.TYPE_STRING,
+                                       gobject.TYPE_STRING,
+                                       gobject.TYPE_STRING)
+            self._treeview.set_model(self.model)
+            self._treeview.append_column(gtk.TreeViewColumn(_('Path'),
+                                         gtk.CellRendererText(), text=0))
+            self._treeview.append_column(gtk.TreeViewColumn(_('Type'),
+                                         gtk.CellRendererText(), text=1))
+            self._treeview.set_search_column(0)
+            for conflict in self.wt.conflicts():
+                if conflict.typestring == 'path conflict':
+                    t = _("path conflict")
+                elif conflict.typestring == 'contents conflict':
+                    t = _("contents conflict")
+                elif conflict.typestring == 'text conflict':
+                    t = _("text conflict")
+                elif conflict.typestring == 'duplicate id':
+                    t = _("duplicate id")
+                elif conflict.typestring == 'duplicate':
+                    t = _("duplicate")
+                elif conflict.typestring == 'parent loop':
+                    t = _("parent loop")
+                elif conflict.typestring == 'unversioned parent':
+                    t = _("unversioned parent")
+                elif conflict.typestring == 'missing parent':
+                    t = _("missing parent")
+                elif conflict.typestring == 'deleting parent':
+                    t = _("deleting parent")
+                else:
+                    t = _("unknown type of conflict")
+                
+                self.model.append([ conflict.path, t, conflict.typestring ]) 
+    
+    def _get_selected_file(self):
+        """ Return the selected conflict's filename. """
+        treeselection = self._treeview.get_selection()
+        (model, iter) = treeselection.get_selected()
+        
+        if iter is None:
+            return None
+        else:
+            return model.get_value(iter, 0)
+    
+    def _get_selected_type(self):
+        """ Return the type of the selected conflict. """
+        treeselection = self._treeview.get_selection()
+        (model, iter) = treeselection.get_selected()
+        
+        if iter is None:
+            return None
+        else:
+            return model.get_value(iter, 2)
+    
+    def _on_diff3_clicked(self, widget):
+        """ Launch external utility to resolve conflicts. """
+        self._set_diff3(self._entry_diff3.get_text())
+        selected = self._get_selected_file()
+        if selected is None:
+            error_dialog(_('No file was selected'),
+                         _('Please select a file from the list.'))
+            return
+        elif self._get_selected_type() == 'text conflict':
+            base = self.wt.abspath(selected) + '.BASE'
+            this = self.wt.abspath(selected) + '.THIS'
+            other = self.wt.abspath(selected) + '.OTHER'
+            os.system(self._entry_diff3.get_text() + ' ' + base + ' ' + this + ' ' + other)
+        else:
+            warning_dialog(_('Cannot resolve conflict'),
+                           _('Only conflicts on the text of files can be resolved with Olive at the moment. Content conflicts, on the structure of the tree, need to be resolved using the command line.'))
+            return

=== modified file 'dialog.py'
--- dialog.py	2007-02-03 14:18:57 +0000
+++ dialog.py	2007-02-04 12:11:31 +0000
@@ -26,21 +26,15 @@
 
 def about():
     """ Display the AboutDialog. """
-    version = None
-    try:
-        import bzrlib.plugins.gtk
-    except ImportError:
-        version = 'N/A'
-    else:
-        version = bzrlib.plugins.gtk.__version__
-    from guifiles import GLADEFILENAME
+    from bzrlib.plugins.gtk import __version__
+    from bzrlib.plugins.gtk.olive.guifiles import GLADEFILENAME
 
     # Load AboutDialog description
     dglade = gtk.glade.XML(GLADEFILENAME, 'aboutdialog')
     dialog = dglade.get_widget('aboutdialog')
 
     # Set version
-    dialog.set_version(version)
+    dialog.set_version(__version__)
 
     dialog.run()
     # Destroy the dialog

=== modified file 'genpot.sh'
--- genpot.sh	2006-09-25 01:58:44 +0000
+++ genpot.sh	2007-02-16 17:17:28 +0000
@@ -23,6 +23,7 @@
 fi
 xgettext -L python -o po/olive-gtk.pot olive-gtk
 xgettext -j -o po/olive-gtk.pot olive.glade
+xgettext -o po/olive-gtk.pot *.py
 cd olive/
 xgettext -j -o ../po/olive-gtk.pot *.py
 #cd viz

=== modified file 'olive-gtk'
--- olive-gtk	2007-02-03 15:24:48 +0000
+++ olive-gtk	2007-02-04 12:11:31 +0000
@@ -82,7 +82,7 @@
 load_plugins()
 
 import bzrlib.ui
-import ui
+import bzrlib.plugins.gtk.ui as ui
 bzrlib.ui.ui_factory = ui.GtkUIFactory()
 
 from olive import OliveGtk

=== modified file 'olive.glade'
--- olive.glade	2007-02-01 14:52:43 +0000
+++ olive.glade	2007-02-04 12:05:45 +0000
@@ -341,6 +341,15 @@
 		      <signal name="activate" handler="on_menuitem_branch_missing_revisions_activate" last_modification_time="Sat, 02 Sep 2006 14:01:29 GMT"/>
 		    </widget>
 		  </child>
+		  
+		  <child>
+		    <widget class="GtkMenuItem" id="menuitem_branch_conflicts">
+		      <property name="visible">True</property>
+		      <property name="label" translatable="yes">Con_flicts...</property>
+		      <property name="use_underline">True</property>
+		      <signal name="activate" handler="on_menuitem_branch_conflicts_activate" last_modification_time="Sun, 04 Feb 2007 12:54:00 GMT"/>
+		    </widget>
+		  </child>
 		</widget>
 	      </child>
 	    </widget>

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2007-02-03 16:03:23 +0000
+++ olive/__init__.py	2007-02-15 18:55:47 +0000
@@ -33,6 +33,7 @@
 
 from bzrlib.branch import Branch
 import bzrlib.errors as bzrerrors
+from bzrlib.lazy_import import lazy_import
 from bzrlib.workingtree import WorkingTree
 
 from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog, warning_dialog
@@ -40,10 +41,13 @@
 from guifiles import GLADEFILENAME
 
 from bzrlib.plugins.gtk.diff import DiffWindow
-from bzrlib.plugins.gtk.viz.branchwin import BranchWindow
+lazy_import(globals(), """
+from bzrlib.plugins.gtk.viz import branchwin
+""")
 from bzrlib.plugins.gtk.annotate.gannotate import GAnnotateWindow
 from bzrlib.plugins.gtk.annotate.config import GAnnotateConfig
 from bzrlib.plugins.gtk.commit import CommitDialog
+from bzrlib.plugins.gtk.conflicts import ConflictsDialog
 from bzrlib.plugins.gtk.push import PushDialog
 
 class OliveGtk:
@@ -86,6 +90,7 @@
         self.menuitem_branch_commit = self.toplevel.get_widget('menuitem_branch_commit')
         self.menuitem_branch_status = self.toplevel.get_widget('menuitem_branch_status')
         self.menuitem_branch_missing = self.toplevel.get_widget('menuitem_branch_missing_revisions')
+        self.menuitem_branch_conflicts = self.toplevel.get_widget('menuitem_branch_conflicts')
         self.menuitem_stats = self.toplevel.get_widget('menuitem_stats')
         self.menuitem_stats_diff = self.toplevel.get_widget('menuitem_stats_diff')
         self.menuitem_stats_log = self.toplevel.get_widget('menuitem_stats_log')
@@ -126,6 +131,7 @@
                 "on_menuitem_branch_pull_activate": self.on_menuitem_branch_pull_activate,
                 "on_menuitem_branch_status_activate": self.on_menuitem_branch_status_activate,
                 "on_menuitem_branch_missing_revisions_activate": self.on_menuitem_branch_missing_revisions_activate,
+                "on_menuitem_branch_conflicts_activate": self.on_menuitem_branch_conflicts_activate,
                 "on_menuitem_stats_diff_activate": self.on_menuitem_stats_diff_activate,
                 "on_menuitem_stats_log_activate": self.on_menuitem_stats_log_activate,
                 "on_menuitem_stats_infos_activate": self.on_menuitem_stats_infos_activate,
@@ -244,6 +250,13 @@
             
             commit.destroy()
     
+    def on_menuitem_branch_conflicts_activate(self, widget):
+        """ Branch/Conflicts... menu handler. """
+        conflicts = ConflictsDialog(self.wt, self.window)
+        response = conflicts.run()
+        if response != gtk.RESPONSE_NONE:
+            conflicts.destroy()
+    
     def on_menuitem_branch_merge_activate(self, widget):
         """ Branch/Merge... menu handler. """
         from bzrlib.plugins.gtk.merge import MergeDialog
@@ -425,7 +438,7 @@
     
     def on_menuitem_stats_log_activate(self, widget):
         """ Statistics/Log... menu handler. """
-        window = BranchWindow()
+        window = branchwin.BranchWindow()
         window.set_branch(self.wt.branch, self.wt.branch.last_revision(), None)
         window.show()
     
@@ -725,6 +738,7 @@
         self.menuitem_branch_commit.set_sensitive(not self.notbranch)
         self.menuitem_branch_status.set_sensitive(not self.notbranch)
         self.menuitem_branch_missing.set_sensitive(not self.notbranch)
+        self.menuitem_branch_conflicts.set_sensitive(not self.notbranch)
         self.menuitem_stats.set_sensitive(not self.notbranch)
         self.menuitem_add_files.set_sensitive(not self.notbranch)
         self.menuitem_remove_files.set_sensitive(not self.notbranch)

=== removed file 'po/hu.po'
--- po/hu.po	2006-09-04 01:02:20 +0000
+++ po/hu.po	1970-01-01 00:00:00 +0000
@@ -1,1077 +0,0 @@
-# Hungarian translations for PACKAGE package.
-# Copyright (C) 2006 THE PACKAGE'S COPYRIGHT HOLDER
-# This file is distributed under the same license as the PACKAGE package.
-# Szilveszter Farkas (Phanatic) <Szilveszter.Farkas@gmail.com>, 2006.
-#
-msgid ""
-msgstr ""
-"Project-Id-Version: PACKAGE VERSION\n"
-"Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2006-09-02 16:23+0200\n"
-"PO-Revision-Date: 2006-09-04 02:58+0200\n"
-"Last-Translator: Szilveszter Farkas (Phanatic) <Szilveszter.Farkas@gmail."
-"com>\n"
-"Language-Team: Hungarian <translation-team-hu@lists.sourceforge.net>\n"
-"MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=UTF-8\n"
-"Content-Transfer-Encoding: 8bit\n"
-"Plural-Forms: nplurals=1; plural=0;\n"
-
-#: olive-gtk:40
-#, python-format
-msgid ""
-"bzr: error: cannot find a suitable python interpreter (need %d.%d or later)"
-msgstr ""
-
-#: olive-gtk:52
-msgid ""
-"You need to install python-glade2 and/or pygtk2 (gtk2) or set your "
-"PYTHONPATH correctly.\n"
-"try: export PYTHONPATH=/usr/local/lib/python2.4/site-packages/"
-msgstr ""
-
-#: olive.glade:9
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:41
-msgid "_File"
-msgstr ""
-
-#: olive.glade:50
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:71
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:98
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:113
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:122
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:150
-msgid "_View"
-msgstr ""
-
-#: olive.glade:160
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:176
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:189 olive.glade:1237
-msgid "_Branch"
-msgstr ""
-
-#: olive.glade:198
-msgid "_Initialize"
-msgstr ""
-
-#: olive.glade:207
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:216
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:231
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:251
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:277
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:303
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:312
-msgid "_Missing revisions"
-msgstr ""
-
-#: olive.glade:325
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:334
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:354
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:374
-msgid "_Informations..."
-msgstr ""
-
-#: olive.glade:387
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:424
-msgid "Refresh"
-msgstr ""
-
-#: olive.glade:441 menu.py:73
-msgid "Diff"
-msgstr ""
-
-#: olive.glade:458
-msgid "Log"
-msgstr ""
-
-#: olive.glade:488 commit.py:118 menu.py:69
-msgid "Commit"
-msgstr ""
-
-#: olive.glade:518
-msgid "Pull"
-msgstr ""
-
-#: olive.glade:535
-msgid "Push"
-msgstr ""
-
-#: olive.glade:649
-msgid "Olive - Commit"
-msgstr ""
-
-#: olive.glade:686
-msgid "Please select the file(s) to commit:"
-msgstr ""
-
-#: olive.glade:753
-msgid "Please specify a commit message:"
-msgstr ""
-
-#: olive.glade:827
-msgid "_Local only commit (works in checkouts)"
-msgstr ""
-
-#: olive.glade:846
-msgid "_Strict commit (fails if unknown files are present)"
-msgstr ""
-
-#: olive.glade:865
-msgid "_Force commit (even do it if nothing has changed)"
-msgstr ""
-
-#: olive.glade:947
-msgid "_Commit"
-msgstr ""
-
-#: olive.glade:987
-msgid "Olive - Branch"
-msgstr ""
-
-#: olive.glade:1021 olive.glade:2042
-msgid "Branch location:"
-msgstr ""
-
-#: olive.glade:1049 olive.glade:2070
-msgid "Destination:"
-msgstr ""
-
-#: olive.glade:1077 olive.glade:2098
-msgid "Please select a folder"
-msgstr ""
-
-#: olive.glade:1117 olive.glade:2138
-msgid "Revision number:"
-msgstr ""
-
-#: olive.glade:1278
-msgid "Olive"
-msgstr ""
-
-#: olive.glade:1279
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:1282
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:1284
-msgid "translator-credits"
-msgstr ""
-
-#: olive.glade:1290
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:1315
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:1341 olive.glade:1534
-msgid "Selected only"
-msgstr ""
-
-#: olive.glade:1360
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:1443
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:1483
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:1508
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: olive.glade:1553
-msgid "All files with status 'added'"
-msgstr ""
-
-#: olive.glade:1636
-msgid "_Remove"
-msgstr ""
-
-#: olive.glade:1676
-msgid "Olive - Push"
-msgstr ""
-
-#: olive.glade:1702
-msgid "Push to _default location"
-msgstr ""
-
-#: olive.glade:1725
-msgid "(no location known)"
-msgstr ""
-
-#: olive.glade:1741
-msgid "Push to _specific location"
-msgstr ""
-
-#: olive.glade:1779
-msgid "_Remember as default location"
-msgstr ""
-
-#: olive.glade:1797
-msgid "_Create the path leading up to the location"
-msgstr ""
-
-#: olive.glade:1816
-msgid "_Overwrite target if diverged"
-msgstr ""
-
-#: olive.glade:1859
-msgid "(click the Test button to check write access)"
-msgstr ""
-
-#: olive.glade:1899
-msgid "_Test"
-msgstr ""
-
-#: olive.glade:1968
-msgid "_Push"
-msgstr ""
-
-#: olive.glade:2008
-msgid "Olive - Checkout"
-msgstr ""
-
-#: olive.glade:2188
-msgid "Lightweight checkout"
-msgstr ""
-
-#: olive.glade:2280
-msgid "C_heckout"
-msgstr ""
-
-#: olive.glade:2321
-msgid "Olive - Diff"
-msgstr ""
-
-#: olive.glade:2438
-msgid "Olive - Status"
-msgstr ""
-
-#: olive.glade:2522
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:2568
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:2650
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:2690
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:2721
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:2746
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:2834
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:2873
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:2904
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:3020
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:3059
-msgid "Olive - Informations"
-msgstr ""
-
-#: olive.glade:3099
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:3126
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:3153
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:3180
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:3207
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:3234
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:3261
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:3288 olive.glade:3314 olive.glade:3340 olive.glade:3366
-#: olive.glade:3392 olive.glade:3418 olive.glade:3444 olive.glade:3572
-#: olive.glade:3598 olive.glade:3780 olive.glade:3806 olive.glade:3832
-#: olive.glade:3858 olive.glade:4013 olive.glade:4039 olive.glade:4065
-#: olive.glade:4193 olive.glade:4219 olive.glade:4509 olive.glade:4535
-#: olive.glade:4561 olive.glade:4587 olive.glade:4613 olive.glade:4639
-#: olive.glade:4665 olive.glade:4691 olive.glade:4900 olive.glade:4926
-#: olive.glade:4952 olive.glade:4978 olive.glade:5004 olive.glade:5132
-#: olive.glade:5158
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:3473 olive.glade:5282
-msgid "Location:"
-msgstr ""
-
-#: olive.glade:3518
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:3545
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:3627
-msgid "Related branches:"
-msgstr ""
-
-#: olive.glade:3672
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:3699
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:3726
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:3753
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:3887
-msgid "Format:"
-msgstr ""
-
-#: olive.glade:3932
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:3959
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:3986
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:4094
-msgid "Lock status:"
-msgstr ""
-
-#: olive.glade:4139
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:4166
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:4248
-msgid "Missing revisions:"
-msgstr ""
-
-#: olive.glade:4293
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:4320
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:4347
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:4374
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:4401
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:4428
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:4455
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:4482
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:4720
-msgid "In the working tree:"
-msgstr ""
-
-#: olive.glade:4765
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:4792
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:4819
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:4846
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:4873
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:5033
-msgid "Branch history:"
-msgstr ""
-
-#: olive.glade:5078
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:5105
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:5187
-msgid "Revision store:"
-msgstr ""
-
-#: olive.glade:5248
-msgid "Edit bookmark - Olive"
-msgstr ""
-
-#: olive.glade:5310
-msgid "Title:"
-msgstr ""
-
-#: add.py:70 menu.py:132 menu.py:154 move.py:69 remove.py:70 rename.py:67
-msgid "No file was selected"
-msgstr ""
-
-#: add.py:71 menu.py:133 menu.py:155 remove.py:71
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: add.py:78 add.py:89 commit.py:96 commit.py:171 diff.py:106 handler.py:82
-#: handler.py:109 info.py:485 log.py:63 menu.py:139 menu.py:161 push.py:84
-#: push.py:124 push.py:154 remove.py:78 remove.py:94 status.py:139
-msgid "Directory is not a branch"
-msgstr ""
-
-#: add.py:79 add.py:90 commit.py:97 commit.py:172 diff.py:107 handler.py:83
-#: handler.py:110 info.py:486 log.py:64 menu.py:140 menu.py:162 push.py:85
-#: push.py:125 push.py:155 remove.py:79 remove.py:95 status.py:140
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: bookmark.py:64
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:65
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: branch.py:66 checkout.py:66
-msgid "Missing branch location"
-msgstr ""
-
-#: branch.py:67 checkout.py:67
-msgid "You must specify a branch location."
-msgstr ""
-
-#: branch.py:81
-msgid "Non existing source"
-msgstr ""
-
-#: branch.py:82
-#, python-format
-msgid ""
-"The location (%s)\n"
-"doesn't exist."
-msgstr ""
-
-#: branch.py:86 checkout.py:89
-msgid "Target already exists"
-msgstr ""
-
-#: branch.py:87 checkout.py:90
-#, python-format
-msgid ""
-"Target directory (%s)\n"
-"already exists. Please select another target."
-msgstr ""
-
-#: branch.py:91 checkout.py:94 push.py:132 push.py:159
-msgid "Non existing parent directory"
-msgstr ""
-
-#: branch.py:92 checkout.py:95 push.py:133 push.py:160
-#, python-format
-msgid ""
-"The parent directory (%s)\n"
-"doesn't exist."
-msgstr ""
-
-#: branch.py:96
-msgid "Non existing revision"
-msgstr ""
-
-#: branch.py:97
-msgid "The revision you specified doesn't exist."
-msgstr ""
-
-#: branch.py:101 checkout.py:84
-msgid "Location is not a branch"
-msgstr ""
-
-#: branch.py:102 checkout.py:85
-msgid "The specified location has to be a branch."
-msgstr ""
-
-#: branch.py:109
-msgid "Branching successful"
-msgstr ""
-
-#: branch.py:110
-#, python-format
-msgid "%d revision(s) branched."
-msgstr ""
-
-#: commit.py:120
-msgid "Path"
-msgstr ""
-
-#: commit.py:122
-msgid "Type"
-msgstr ""
-
-#: commit.py:126 __init__.py:208 __init__.py:427
-msgid "added"
-msgstr ""
-
-#: commit.py:129 __init__.py:206 __init__.py:425
-msgid "removed"
-msgstr ""
-
-#: commit.py:132 __init__.py:204 __init__.py:423
-msgid "renamed"
-msgstr ""
-
-#: commit.py:135 __init__.py:210 __init__.py:429
-msgid "modified"
-msgstr ""
-
-#: commit.py:176
-msgid "Directory is not a checkout"
-msgstr ""
-
-#: commit.py:177
-msgid "You can perform local commit only on checkouts."
-msgstr ""
-
-#: commit.py:181
-msgid "No changes to commit"
-msgstr ""
-
-#: commit.py:182
-msgid "Try force commit if you want to commit anyway."
-msgstr ""
-
-#: commit.py:186
-msgid "Conflicts in tree"
-msgstr ""
-
-#: commit.py:187
-msgid "You need to resolve the conflicts before committing."
-msgstr ""
-
-#: commit.py:191
-msgid "Strict commit failed"
-msgstr ""
-
-#: commit.py:192
-msgid ""
-"There are unknown files in the working tree.\n"
-"Please add or delete them."
-msgstr ""
-
-#: commit.py:196
-msgid "Bound branch is out of date"
-msgstr ""
-
-#: commit.py:197
-#, python-format
-msgid "%s"
-msgstr ""
-
-#: diff.py:149 diffwin.py:144
-msgid "Complete Diff"
-msgstr ""
-
-#: diff.py:152 status.py:107 diffwin.py:147
-msgid "Added"
-msgstr ""
-
-#: diff.py:157 status.py:112 diffwin.py:152
-msgid "Removed"
-msgstr ""
-
-#: diff.py:162 status.py:117 diffwin.py:157
-msgid "Renamed"
-msgstr ""
-
-#: diff.py:168 status.py:123 diffwin.py:163
-msgid "Modified"
-msgstr ""
-
-#: handler.py:85
-msgid "Connection error"
-msgstr ""
-
-#: handler.py:86
-msgid ""
-"Cannot connect to remote location.\n"
-"Please try again later."
-msgstr ""
-
-#: handler.py:88 handler.py:112
-msgid "Parent location is unknown"
-msgstr ""
-
-#: handler.py:89
-msgid "Cannot determine missing revisions if no parent location is known."
-msgstr ""
-
-#: handler.py:92
-msgid "There are missing revisions"
-msgstr ""
-
-#: handler.py:93
-#, python-format
-msgid "%d revision(s) missing."
-msgstr ""
-
-#: handler.py:95
-msgid "Local branch up to date"
-msgstr ""
-
-#: handler.py:96
-msgid "There are no missing revisions."
-msgstr ""
-
-#: handler.py:113
-msgid "Pulling is not possible until there is no parent location."
-msgstr ""
-
-#: handler.py:115
-msgid "Pull successful"
-msgstr ""
-
-#: handler.py:116
-#, python-format
-msgid "%d revision(s) pulled."
-msgstr ""
-
-#: handler.py:139
-msgid "Directory is already a branch"
-msgstr ""
-
-#: handler.py:140
-#, python-format
-msgid ""
-"The current directory (%s) is already a branch.\n"
-"You can start using it, or initialize another directory."
-msgstr ""
-
-#: handler.py:142
-msgid "Branch without a working tree"
-msgstr ""
-
-#: handler.py:143
-#, python-format
-msgid ""
-"The current directory (%s)\n"
-"is a branch without a working tree."
-msgstr ""
-
-#: handler.py:147
-msgid "Ininialize successful"
-msgstr ""
-
-#: handler.py:148
-msgid "Directory successfully initialized."
-msgstr ""
-
-#: handler.py:293
-msgid "We feel sorry"
-msgstr ""
-
-#: handler.py:294
-msgid "This feature is not yet implemented."
-msgstr ""
-
-#: __init__.py:58
-msgid "Glade file cannot be found."
-msgstr ""
-
-#: __init__.py:146 __init__.py:365
-msgid "Bookmarks"
-msgstr ""
-
-#: __init__.py:153 menu.py:77
-msgid "Bookmark"
-msgstr ""
-
-#: __init__.py:212 __init__.py:431
-msgid "unchanged"
-msgstr ""
-
-#: __init__.py:214 __init__.py:433
-msgid "unknown"
-msgstr ""
-
-#: __init__.py:219
-msgid "Filename"
-msgstr ""
-
-#: __init__.py:220
-msgid "Status"
-msgstr ""
-
-#: menu.py:49
-msgid "UI description file cannot be found."
-msgstr ""
-
-#: menu.py:61
-msgid "Add"
-msgstr ""
-
-#: menu.py:62
-msgid "Add the selected file"
-msgstr ""
-
-#: menu.py:65 menu.py:85
-msgid "Remove"
-msgstr ""
-
-#: menu.py:66
-msgid "Remove the selected file"
-msgstr ""
-
-#: menu.py:70
-msgid "Commit the changes"
-msgstr ""
-
-#: menu.py:74
-msgid "Show the diff of the file"
-msgstr ""
-
-#: menu.py:78
-msgid "Bookmark current location"
-msgstr ""
-
-#: menu.py:81
-msgid "Edit"
-msgstr ""
-
-#: menu.py:82
-msgid "Edit the selected bookmark"
-msgstr ""
-
-#: menu.py:86
-msgid "Remove the selected bookmark"
-msgstr ""
-
-#: menu.py:89
-msgid "Selected..."
-msgstr ""
-
-#: menu.py:90
-msgid "Show the differences of the selected file"
-msgstr ""
-
-#: menu.py:93
-msgid "All..."
-msgstr ""
-
-#: menu.py:94
-msgid "Show the differences of all files"
-msgstr ""
-
-#: menu.py:165 remove.py:83
-msgid "File not versioned"
-msgstr ""
-
-#: menu.py:166 remove.py:84
-msgid "The selected file is not versioned."
-msgstr ""
-
-#: menu.py:188
-msgid "Bookmark successfully added"
-msgstr ""
-
-#: menu.py:189
-msgid ""
-"The current directory was bookmarked. You can reach\n"
-"it by selecting it from the left panel."
-msgstr ""
-
-#: menu.py:191
-msgid "Location already bookmarked"
-msgstr ""
-
-#: menu.py:192
-msgid ""
-"The current directory is already bookmarked.\n"
-"See the left panel for reference."
-msgstr ""
-
-#: mkdir.py:67
-msgid "No directory name given"
-msgstr ""
-
-#: mkdir.py:68
-msgid "Please specify a desired name for the new directory."
-msgstr ""
-
-#: mkdir.py:78 mkdir.py:90
-msgid "Directory already exists"
-msgstr ""
-
-#: mkdir.py:79 mkdir.py:91
-msgid "Please specify another name to continue."
-msgstr ""
-
-#: mkdir.py:82
-msgid "Directory is not in a branch"
-msgstr ""
-
-#: mkdir.py:83
-msgid "You can only create a non-versioned directory."
-msgstr ""
-
-#: move.py:70 rename.py:68
-msgid "Please select a file from the list to proceed."
-msgstr ""
-
-#: move.py:79 rename.py:83
-msgid "File is not in a branch"
-msgstr ""
-
-#: move.py:80 rename.py:84
-msgid "The selected file is not in a branch."
-msgstr ""
-
-#: move.py:83 rename.py:87
-msgid "Not the same branch"
-msgstr ""
-
-#: move.py:84 rename.py:88
-msgid "The destination is not in the same branch."
-msgstr ""
-
-#: push.py:128
-msgid "Push location is unknown"
-msgstr ""
-
-#: push.py:129
-msgid "Please specify a location manually."
-msgstr ""
-
-#: push.py:136 push.py:164
-msgid "Branches have been diverged"
-msgstr ""
-
-#: push.py:137 push.py:165
-msgid ""
-"You cannot push if branches have diverged. Use the\n"
-"overwrite option if you want to push anyway."
-msgstr ""
-
-#: push.py:144
-msgid "No location specified"
-msgstr ""
-
-#: push.py:145
-msgid "Please specify a location or use the default."
-msgstr ""
-
-#: push.py:169
-msgid "Path prefix not created"
-msgstr ""
-
-#: push.py:170
-msgid ""
-"The path leading up to the specified location couldn't\n"
-"be created."
-msgstr ""
-
-#: push.py:180
-msgid "Push successful"
-msgstr ""
-
-#: push.py:181
-#, python-format
-msgid "%d revision(s) pushed."
-msgstr ""
-
-#: push.py:199
-msgid "<b>Write access is available most probably</b>"
-msgstr ""
-
-#: push.py:203
-msgid "<b>No write access</b>"
-msgstr ""
-
-#: push.py:207
-msgid "<b>Could not determine</b>"
-msgstr ""
-
-#: remove.py:99
-msgid "No matching files"
-msgstr ""
-
-#: remove.py:100
-msgid "No added files were found in the working tree."
-msgstr ""
-
-#: rename.py:72
-msgid "Filename not given"
-msgstr ""
-
-#: rename.py:73
-msgid "Please specify a new name for the file."
-msgstr ""
-
-#: status.py:130
-msgid "Unknown"
-msgstr ""
-
-#: branchwin.py:113
-msgid "Message"
-msgstr ""
-
-#: branchwin.py:122
-msgid "Committer"
-msgstr ""
-
-#: branchwin.py:130
-msgid "Date"
-msgstr ""
-
-#: branchwin.py:188
-msgid "<b>Revision:</b>"
-msgstr ""
-
-#: branchwin.py:204
-msgid "<b>Committer:</b>"
-msgstr ""
-
-#: branchwin.py:220
-msgid "<b>Branch nick:</b>"
-msgstr ""
-
-#: branchwin.py:236
-msgid "<b>Timestamp:</b>"
-msgstr ""
-
-#: branchwin.py:258
-msgid "<b>Parents:</b>"
-msgstr ""

=== modified file 'po/olive-gtk.pot'
--- po/olive-gtk.pot	2006-09-25 01:58:44 +0000
+++ po/olive-gtk.pot	2007-02-16 17:17:28 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2006-09-25 01:23+0200\n"
+"POT-Creation-Date: 2007-02-16 18:09+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -16,1020 +16,798 @@
 "Content-Type: text/plain; charset=CHARSET\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: olive-gtk:40
-#, python-format
-msgid ""
-"bzr: error: cannot find a suitable python interpreter (need %d.%d or later)"
-msgstr ""
-
-#: olive-gtk:52
-msgid ""
-"You need to install python-glade2 and/or pygtk2 (gtk2) or set your "
-"PYTHONPATH correctly.\n"
-"try: export PYTHONPATH=/usr/local/lib/python2.4/site-packages/"
-msgstr ""
-
-#: olive.glade:9
-msgid "Olive - Bazaar GUI"
-msgstr ""
-
-#: olive.glade:41
-msgid "_File"
-msgstr ""
-
-#: olive.glade:50
-msgid "_Add file(s)..."
-msgstr ""
-
-#: olive.glade:71
-msgid "Remove file(s)..."
-msgstr ""
-
-#: olive.glade:98
-msgid "Make _directory..."
-msgstr ""
-
-#: olive.glade:113
-msgid "_Rename..."
-msgstr ""
-
-#: olive.glade:122
-msgid "_Move..."
-msgstr ""
-
-#: olive.glade:150
-msgid "_View"
-msgstr ""
-
-#: olive.glade:160
-msgid "Show _hidden files"
-msgstr ""
-
-#: olive.glade:176
-msgid "_Refresh"
-msgstr ""
-
-#: olive.glade:189 olive.glade:1254
+#: branch.py:50
 msgid "_Branch"
 msgstr ""
 
-#: olive.glade:198
-msgid "_Initialize"
-msgstr ""
-
-#: olive.glade:207
-msgid "_Get..."
-msgstr ""
-
-#: olive.glade:216
-msgid "C_heckout..."
-msgstr ""
-
-#: olive.glade:231
-msgid "Pu_ll"
-msgstr ""
-
-#: olive.glade:251
-msgid "Pu_sh..."
-msgstr ""
-
-#: olive.glade:277
-msgid "_Commit..."
-msgstr ""
-
-#: olive.glade:303
-msgid "S_tatus..."
-msgstr ""
-
-#: olive.glade:312
-msgid "_Missing revisions"
-msgstr ""
-
-#: olive.glade:325
-msgid "_Statistics"
-msgstr ""
-
-#: olive.glade:334
-msgid "_Differences..."
-msgstr ""
-
-#: olive.glade:354
-msgid "_Log..."
-msgstr ""
-
-#: olive.glade:374
-msgid "_Information..."
-msgstr ""
-
-#: olive.glade:387
-msgid "_Help"
-msgstr ""
-
-#: olive.glade:424
-msgid "Refresh"
-msgstr ""
-
-#: olive.glade:441 menu.py:78
-msgid "Diff"
-msgstr ""
-
-#: olive.glade:458
-msgid "Log"
-msgstr ""
-
-#: olive.glade:488 commit.py:116 menu.py:74
-msgid "Commit"
-msgstr ""
-
-#: olive.glade:518
-msgid "Pull"
-msgstr ""
-
-#: olive.glade:535
-msgid "Push"
-msgstr ""
-
-#: olive.glade:666
-msgid "Olive - Commit"
-msgstr ""
-
-#: olive.glade:703
-msgid "Please select the file(s) to commit:"
-msgstr ""
-
-#: olive.glade:770
-msgid "Please specify a commit message:"
-msgstr ""
-
-#: olive.glade:844
-msgid "_Local only commit (works in checkouts)"
-msgstr ""
-
-#: olive.glade:863
-msgid "_Strict commit (fails if unknown files are present)"
-msgstr ""
-
-#: olive.glade:882
-msgid "_Force commit (even do it if nothing has changed)"
-msgstr ""
-
-#: olive.glade:964
-msgid "_Commit"
-msgstr ""
-
-#: olive.glade:1004
-msgid "Olive - Branch"
-msgstr ""
-
-#: olive.glade:1038 olive.glade:2062
+#: branch.py:53 checkout.py:52
+msgid "Please select a folder"
+msgstr ""
+
+#: branch.py:55 checkout.py:54
 msgid "Branch location:"
 msgstr ""
 
-#: olive.glade:1066 olive.glade:2090
+#: branch.py:56 checkout.py:55
 msgid "Destination:"
 msgstr ""
 
-#: olive.glade:1094 olive.glade:2118
-msgid "Please select a folder"
-msgstr ""
-
-#: olive.glade:1134 olive.glade:2158
-msgid "Revision number:"
-msgstr ""
-
-#: olive.glade:1295
-msgid "Olive"
-msgstr ""
-
-#: olive.glade:1296
-msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
-msgstr ""
-
-#: olive.glade:1299
-msgid "https://launchpad.net/products/olive"
-msgstr ""
-
-#: olive.glade:1301
-msgid "translator-credits"
-msgstr ""
-
-#: olive.glade:1307
-msgid "Olive - Add file(s)"
-msgstr ""
-
-#: olive.glade:1332
-msgid "Which file(s) do you want to add?"
-msgstr ""
-
-#: olive.glade:1358 olive.glade:1551
-msgid "Selected only"
-msgstr ""
-
-#: olive.glade:1377
-msgid "All unknowns recursively"
-msgstr ""
-
-#: olive.glade:1460
-msgid "_Add"
-msgstr ""
-
-#: olive.glade:1500
-msgid "Olive - Remove file(s)"
-msgstr ""
-
-#: olive.glade:1525
-msgid "Which file(s) do you want to remove?"
-msgstr ""
-
-#: olive.glade:1570
-msgid "All files with status 'added'"
-msgstr ""
-
-#: olive.glade:1653
-msgid "_Remove"
-msgstr ""
-
-#: olive.glade:1693
-msgid "Olive - Push"
-msgstr ""
-
-#: olive.glade:1719
-msgid "Push to _default location"
-msgstr ""
-
-#: olive.glade:1742
-msgid "(no location known)"
-msgstr ""
-
-#: olive.glade:1758
-msgid "Push to _specific location"
-msgstr ""
-
-#: olive.glade:1798
-msgid "_Remember as default location"
-msgstr ""
-
-#: olive.glade:1817
-msgid "_Create the path leading up to the location"
-msgstr ""
-
-#: olive.glade:1836
-msgid "_Overwrite target if diverged"
-msgstr ""
-
-#: olive.glade:1879
-msgid "(click the Test button to check write access)"
-msgstr ""
-
-#: olive.glade:1919
-msgid "_Test"
-msgstr ""
-
-#: olive.glade:1988
-msgid "_Push"
-msgstr ""
-
-#: olive.glade:2028
-msgid "Olive - Checkout"
-msgstr ""
-
-#: olive.glade:2208
-msgid "Lightweight checkout"
-msgstr ""
-
-#: olive.glade:2300
-msgid "C_heckout"
-msgstr ""
-
-#: olive.glade:2341
-msgid "Olive - Diff"
-msgstr ""
-
-#: olive.glade:2458
-msgid "Olive - Status"
-msgstr ""
-
-#: olive.glade:2542
-msgid "Olive - Make directory"
-msgstr ""
-
-#: olive.glade:2588
-msgid "_Versioned directory"
-msgstr ""
-
-#: olive.glade:2670
-msgid "_Make directory"
-msgstr ""
-
-#: olive.glade:2710
-msgid "Olive - Move"
-msgstr ""
-
-#: olive.glade:2741
-msgid "Move to"
-msgstr ""
-
-#: olive.glade:2766
-msgid "Select a directory"
-msgstr ""
-
-#: olive.glade:2854
-msgid "_Move"
-msgstr ""
-
-#: olive.glade:2893
-msgid "Olive - Rename"
-msgstr ""
-
-#: olive.glade:2924
-msgid "Rename to"
-msgstr ""
-
-#: olive.glade:3040
-msgid "_Rename"
-msgstr ""
-
-#: olive.glade:3079
-msgid "Olive - Information"
-msgstr ""
-
-#: olive.glade:3131
-msgid "Light checkout root: "
-msgstr ""
-
-#: olive.glade:3158
-msgid "Shared repository: "
-msgstr ""
-
-#: olive.glade:3185
-msgid "Repository branch: "
-msgstr ""
-
-#: olive.glade:3212
-msgid "Checkout of branch: "
-msgstr ""
-
-#: olive.glade:3239
-msgid "Repository checkout: "
-msgstr ""
-
-#: olive.glade:3266
-msgid "Branch root: "
-msgstr ""
-
-#: olive.glade:3293
-msgid "Checkout root: "
-msgstr ""
-
-#: olive.glade:3320 olive.glade:3346 olive.glade:3372 olive.glade:3398
-#: olive.glade:3424 olive.glade:3450 olive.glade:3476 olive.glade:3618
-#: olive.glade:3644 olive.glade:3840 olive.glade:3866 olive.glade:3892
-#: olive.glade:3918 olive.glade:4087 olive.glade:4113 olive.glade:4139
-#: olive.glade:4281 olive.glade:4307 olive.glade:4611 olive.glade:4637
-#: olive.glade:4663 olive.glade:4689 olive.glade:4715 olive.glade:4741
-#: olive.glade:4767 olive.glade:4793 olive.glade:5016 olive.glade:5042
-#: olive.glade:5068 olive.glade:5094 olive.glade:5120 olive.glade:5262
-#: olive.glade:5288
-msgid "(none)"
-msgstr ""
-
-#: olive.glade:3507
-msgid "<b>Location:</b>"
-msgstr ""
-
-#: olive.glade:3564
-msgid "Parent branch: "
-msgstr ""
-
-#: olive.glade:3591
-msgid "Publish to branch: "
-msgstr ""
-
-#: olive.glade:3675
-msgid "<b>Related branches:</b>"
-msgstr ""
-
-#: olive.glade:3732
-msgid "Control format: "
-msgstr ""
-
-#: olive.glade:3759
-msgid "Working tree format: "
-msgstr ""
-
-#: olive.glade:3786
-msgid "Branch format: "
-msgstr ""
-
-#: olive.glade:3813
-msgid "Repository format: "
-msgstr ""
-
-#: olive.glade:3949
-msgid "<b>Format:</b>"
-msgstr ""
-
-#: olive.glade:4006
-msgid "Working tree lock status: "
-msgstr ""
-
-#: olive.glade:4033
-msgid "Branch lock status: "
-msgstr ""
-
-#: olive.glade:4060
-msgid "Repository lock status: "
-msgstr ""
-
-#: olive.glade:4170
-msgid "<b>Lock status:</b>"
-msgstr ""
-
-#: olive.glade:4227
-msgid "Missing revisions in working tree: "
-msgstr ""
-
-#: olive.glade:4254
-msgid "Missing revisions in branch: "
-msgstr ""
-
-#: olive.glade:4338
-msgid "<b>Missing revisions:</b>"
-msgstr ""
-
-#: olive.glade:4395
-msgid "Unchanged files: "
-msgstr ""
-
-#: olive.glade:4422
-msgid "Modified files: "
-msgstr ""
-
-#: olive.glade:4449
-msgid "Added files: "
-msgstr ""
-
-#: olive.glade:4476
-msgid "Removed files: "
-msgstr ""
-
-#: olive.glade:4503
-msgid "Renamed files: "
-msgstr ""
-
-#: olive.glade:4530
-msgid "Unknown files: "
-msgstr ""
-
-#: olive.glade:4557
-msgid "Ignored files: "
-msgstr ""
-
-#: olive.glade:4584
-msgid "Versioned subdirectories: "
-msgstr ""
-
-#: olive.glade:4824
-msgid "<b>In the working tree:</b>"
-msgstr ""
-
-#: olive.glade:4881
-msgid "Revisions in branch: "
-msgstr ""
-
-#: olive.glade:4908
-msgid "Number of commiters: "
-msgstr ""
-
-#: olive.glade:4935
-msgid "Age of branch in days: "
-msgstr ""
-
-#: olive.glade:4962
-msgid "Time of first revision: "
-msgstr ""
-
-#: olive.glade:4989
-msgid "Time of last revision: "
-msgstr ""
-
-#: olive.glade:5151
-msgid "<b>Branch history:</b>"
-msgstr ""
-
-#: olive.glade:5208
-msgid "Revisions in repository: "
-msgstr ""
-
-#: olive.glade:5235
-msgid "Size of repository: "
-msgstr ""
-
-#: olive.glade:5319
-msgid "<b>Revision store:</b>"
-msgstr ""
-
-#: olive.glade:5380
-msgid "Edit bookmark - Olive"
-msgstr ""
-
-#: olive.glade:5414
-msgid "Location:"
-msgstr ""
-
-#: olive.glade:5442
-msgid "Title:"
-msgstr ""
-
-#: add.py:70 menu.py:141 menu.py:161 menu.py:188 move.py:68 remove.py:69
-#: rename.py:66
-msgid "No file was selected"
-msgstr ""
-
-#: add.py:71 menu.py:142 menu.py:162 menu.py:189 remove.py:70
-msgid ""
-"Please select a file from the list,\n"
-"or choose the other option."
-msgstr ""
-
-#: add.py:78 add.py:89 commit.py:92 commit.py:169 diff.py:106 handler.py:86
-#: handler.py:126 handler.py:138 info.py:562 log.py:63 menu.py:148 menu.py:170
-#: push.py:88 push.py:127 push.py:157 remove.py:78 remove.py:95 status.py:149
-msgid "Directory is not a branch"
-msgstr ""
-
-#: add.py:79 add.py:90 commit.py:93 commit.py:170 diff.py:107 handler.py:87
-#: handler.py:127 handler.py:139 info.py:563 log.py:64 menu.py:149 menu.py:171
-#: push.py:89 push.py:128 push.py:158 remove.py:79 remove.py:96 status.py:150
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: bookmark.py:64
-msgid "No title given"
-msgstr ""
-
-#: bookmark.py:65
-msgid "Please specify a title to continue."
-msgstr ""
-
-#: branch.py:65 checkout.py:65
+#: branch.py:57 checkout.py:56
+msgid "Branck nick:"
+msgstr ""
+
+#: branch.py:58 checkout.py:57
+msgid "Revision:"
+msgstr ""
+
+#: branch.py:152 checkout.py:154
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:66 checkout.py:66
+#: branch.py:153 checkout.py:155
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:100
+#: branch.py:195
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:101
+#: branch.py:196
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:104
-msgid "Non existing source"
-msgstr ""
-
-#: branch.py:105
-#, python-format
-msgid ""
-"The location (%s)\n"
-"doesn't exist."
-msgstr ""
-
-#: branch.py:109 checkout.py:122
-msgid "Target already exists"
-msgstr ""
-
-#: branch.py:110 checkout.py:123
-#, python-format
-msgid ""
-"Target directory (%s)\n"
-"already exists. Please select another target."
-msgstr ""
-
-#: branch.py:114 checkout.py:127 push.py:135 push.py:162
-msgid "Non existing parent directory"
-msgstr ""
-
-#: branch.py:115 checkout.py:128 push.py:136 push.py:163
-#, python-format
-msgid ""
-"The parent directory (%s)\n"
-"doesn't exist."
-msgstr ""
-
-#: branch.py:119
-msgid "Non existing revision"
-msgstr ""
-
-#: branch.py:120
-msgid "The revision you specified doesn't exist."
-msgstr ""
-
-#: branch.py:124 checkout.py:117
-msgid "Location is not a branch"
-msgstr ""
-
-#: branch.py:125 checkout.py:118
-msgid "The specified location has to be a branch."
-msgstr ""
-
-#: commit.py:118
+#: branch.py:204 checkout.py:186
+msgid "N/A"
+msgstr ""
+
+#: checkout.py:49
+msgid "Check_out"
+msgstr ""
+
+#: checkout.py:61
+msgid "_Lightweight checkout"
+msgstr ""
+
+#: commit.py:61
+msgid "Directory does not have a working tree"
+msgstr ""
+
+#: commit.py:62
+msgid "Operation aborted."
+msgstr ""
+
+#: commit.py:67 errors.py:26 add.py:76 add.py:86 info.py:554
+msgid "Directory is not a branch"
+msgstr ""
+
+#: commit.py:68 errors.py:27 add.py:77 add.py:87 info.py:555
+msgid "You can perform this action only in a branch."
+msgstr ""
+
+#: commit.py:81
+msgid "Comm_it"
+msgstr ""
+
+#: commit.py:83
+msgid "_Only commit locally"
+msgstr ""
+
+#: commit.py:85
+msgid "_Allow unknown files"
+msgstr ""
+
+#: commit.py:87
+msgid "File(s) to commit"
+msgstr ""
+
+#: commit.py:93
+msgid "Commit message:"
+msgstr ""
+
+#: commit.py:97
+msgid "Pending merges"
+msgstr ""
+
+#: commit.py:199
+msgid "Commit with an empty message?"
+msgstr ""
+
+#: commit.py:200
+msgid "You can describe your commit intent in the message."
+msgstr ""
+
+#: commit.py:218
+msgid "Commit with no changes?"
+msgstr ""
+
+#: commit.py:219
+msgid "There are no changes in the working tree."
+msgstr ""
+
+#: commit.py:301 menu.py:77
+msgid "Commit"
+msgstr ""
+
+#: commit.py:303 conflicts.py:108
 msgid "Path"
 msgstr ""
 
-#: commit.py:120
+#: commit.py:305 conflicts.py:110
 msgid "Type"
 msgstr ""
 
-#: commit.py:124
+#: commit.py:312 commit.py:314 commit.py:316 __init__.py:667 __init__.py:863
 msgid "added"
 msgstr ""
 
-#: commit.py:127
+#: commit.py:322 commit.py:324 commit.py:326 __init__.py:665 __init__.py:861
 msgid "removed"
 msgstr ""
 
-#: commit.py:130
+#: commit.py:331
+msgid "renamed and modified"
+msgstr ""
+
+#: commit.py:333 __init__.py:663 __init__.py:859
 msgid "renamed"
 msgstr ""
 
-#: commit.py:133
+#: commit.py:358 commit.py:360 commit.py:362 __init__.py:669 __init__.py:865
 msgid "modified"
 msgstr ""
 
-#: commit.py:174
+#: commit.py:373
+msgid "Date"
+msgstr ""
+
+#: commit.py:375 revbrowser.py:61
+msgid "Committer"
+msgstr ""
+
+#: commit.py:377 revbrowser.py:59
+msgid "Summary"
+msgstr ""
+
+#: conflicts.py:48
+msgid "External utility:"
+msgstr ""
+
+#: conflicts.py:99
+msgid "Conflicts"
+msgstr ""
+
+#: conflicts.py:102
+msgid "No conflicts in working tree."
+msgstr ""
+
+#: conflicts.py:115
+msgid "path conflict"
+msgstr ""
+
+#: conflicts.py:117
+msgid "contents conflict"
+msgstr ""
+
+#: conflicts.py:119
+msgid "text conflict"
+msgstr ""
+
+#: conflicts.py:121
+msgid "duplicate id"
+msgstr ""
+
+#: conflicts.py:123
+msgid "duplicate"
+msgstr ""
+
+#: conflicts.py:125
+msgid "parent loop"
+msgstr ""
+
+#: conflicts.py:127
+msgid "unversioned parent"
+msgstr ""
+
+#: conflicts.py:129
+msgid "missing parent"
+msgstr ""
+
+#: conflicts.py:131
+msgid "deleting parent"
+msgstr ""
+
+#: conflicts.py:133
+msgid "unknown type of conflict"
+msgstr ""
+
+#: conflicts.py:162 __init__.py:371 add.py:67 menu.py:148 menu.py:162
+#: menu.py:184 move.py:79 remove.py:67 remove.py:129 rename.py:69
+msgid "No file was selected"
+msgstr ""
+
+#: conflicts.py:163 __init__.py:372
+msgid "Please select a file from the list."
+msgstr ""
+
+#: conflicts.py:171
+msgid "Cannot resolve conflict"
+msgstr ""
+
+#: conflicts.py:172
+msgid ""
+"Only conflicts on the text of files can be resolved with Olive at the "
+"moment. Content conflicts, on the structure of the tree, need to be resolved "
+"using the command line."
+msgstr ""
+
+#: errors.py:29
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: commit.py:175
+#: errors.py:30
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: commit.py:179
+#: errors.py:32
 msgid "No changes to commit"
 msgstr ""
 
-#: commit.py:180
+#: errors.py:33
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: commit.py:184
+#: errors.py:35
 msgid "Conflicts in tree"
 msgstr ""
 
-#: commit.py:185
+#: errors.py:36
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: commit.py:189
+#: errors.py:38
 msgid "Strict commit failed"
 msgstr ""
 
-#: commit.py:190
+#: errors.py:39
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: commit.py:194
+#: errors.py:41
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: commit.py:195
+#: errors.py:42
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: diff.py:149
-msgid "Complete Diff"
-msgstr ""
-
-#: diff.py:152 status.py:110
+#: errors.py:44
+msgid "File not versioned"
+msgstr ""
+
+#: errors.py:45
+msgid "The selected file is not versioned."
+msgstr ""
+
+#: errors.py:47 push.py:141
+msgid "Branches have been diverged"
+msgstr ""
+
+#: errors.py:48
+msgid ""
+"You cannot push if branches have diverged. Use the\n"
+"overwrite option if you want to push anyway."
+msgstr ""
+
+#: errors.py:50
+msgid "No diff output"
+msgstr ""
+
+#: errors.py:51
+msgid "The selected file hasn't changed."
+msgstr ""
+
+#: errors.py:53
+msgid "No such revision"
+msgstr ""
+
+#: errors.py:54
+msgid "The revision you specified doesn't exist."
+msgstr ""
+
+#: errors.py:56
+msgid "Target already exists"
+msgstr ""
+
+#: errors.py:57
+msgid "Target directory already exists. Please select another target."
+msgstr ""
+
+#: errors.py:59
+msgid "Directory is already a branch"
+msgstr ""
+
+#: errors.py:60
+#, python-format
+msgid ""
+"The current directory (%s) is already a branch.\n"
+"You can start using it, or initialize another directory."
+msgstr ""
+
+#: errors.py:62
+msgid "Branch without a working tree"
+msgstr ""
+
+#: errors.py:63
+#, python-format
+msgid ""
+"The current directory (%s)\n"
+"is a branch without a working tree."
+msgstr ""
+
+#: errors.py:65
+msgid "Unknown bzr error"
+msgstr ""
+
+#: errors.py:67
+msgid "Permission denied"
+msgstr ""
+
+#: errors.py:67
+msgid "permission denied."
+msgstr ""
+
+#: errors.py:69
+msgid "Unknown error"
+msgstr ""
+
+#: merge.py:66
+msgid "Branch not given"
+msgstr ""
+
+#: merge.py:67
+msgid "Please specify a branch to merge from."
+msgstr ""
+
+#: merge.py:75
+msgid "Bazaar command error"
+msgstr ""
+
+#: merge.py:81
+msgid "Merge successful"
+msgstr ""
+
+#: merge.py:82
+msgid "All changes applied successfully."
+msgstr ""
+
+#: merge.py:85
+msgid "Conflicts encountered"
+msgstr ""
+
+#: merge.py:86
+msgid "Please resolve the conflicts manually before committing."
+msgstr ""
+
+#: push.py:47 bookmark.py:45
+msgid "Location:"
+msgstr ""
+
+#: push.py:48
+msgid "(click the Test button to check write access)"
+msgstr ""
+
+#: push.py:49
+msgid "_Remember as default location"
+msgstr ""
+
+#: push.py:51
+msgid "Create the path _leading up to the location"
+msgstr ""
+
+#: push.py:53
+msgid "_Overwrite target if diverged"
+msgstr ""
+
+#: push.py:56
+msgid "_Test"
+msgstr ""
+
+#: push.py:57
+msgid "_Push"
+msgstr ""
+
+#: push.py:119
+msgid "<b>Write access is probably available</b>"
+msgstr ""
+
+#: push.py:123
+msgid "<b>No write access</b>"
+msgstr ""
+
+#: push.py:127
+msgid "<b>Could not determine</b>"
+msgstr ""
+
+#: push.py:142
+msgid ""
+"You cannot push if branches have diverged.\n"
+"Overwrite?"
+msgstr ""
+
+#: push.py:148
+msgid "Push successful"
+msgstr ""
+
+#: push.py:149
+#, python-format
+msgid "%d revision(s) pushed."
+msgstr ""
+
+#: push.py:177
+msgid "Push location is unknown"
+msgstr ""
+
+#: push.py:178
+msgid "Please specify a location manually."
+msgstr ""
+
+#: push.py:202
+msgid "Non existing parent directory"
+msgstr ""
+
+#: push.py:203
+#, python-format
+msgid ""
+"The parent directory (%s)\n"
+"doesn't exist."
+msgstr ""
+
+#: push.py:218
+msgid "Path prefix not created"
+msgstr ""
+
+#: push.py:219
+msgid ""
+"The path leading up to the specified location couldn't\n"
+"be created."
+msgstr ""
+
+#: revbrowser.py:41
+msgid "Please select a revision"
+msgstr ""
+
+#: revbrowser.py:44
+msgid "_Select"
+msgstr ""
+
+#: revbrowser.py:57
+msgid "Revno"
+msgstr ""
+
+#: revbrowser.py:63
+msgid "Time"
+msgstr ""
+
+#: status.py:79
 msgid "Added"
 msgstr ""
 
-#: diff.py:157 status.py:116
+#: status.py:85
 msgid "Removed"
 msgstr ""
 
-#: diff.py:162 status.py:122
+#: status.py:91
 msgid "Renamed"
 msgstr ""
 
-#: diff.py:168 status.py:129
+#: status.py:98
 msgid "Modified"
 msgstr ""
 
-#: handler.py:92 handler.py:131
+#: status.py:106
+msgid "Unknown"
+msgstr ""
+
+#: status.py:111
+msgid "No changes."
+msgstr ""
+
+#: __init__.py:262
+msgid "There are local changes in the branch"
+msgstr ""
+
+#: __init__.py:263
+msgid "Please commit or revert the changes before merging."
+msgstr ""
+
+#: __init__.py:275 __init__.py:300
 msgid "Parent location is unknown"
 msgstr ""
 
-#: handler.py:93
+#: __init__.py:276
 msgid "Cannot determine missing revisions if no parent location is known."
 msgstr ""
 
-#: handler.py:104
+#: __init__.py:287
 msgid "There are missing revisions"
 msgstr ""
 
-#: handler.py:105
+#: __init__.py:288
 #, python-format
 msgid "%d revision(s) missing."
 msgstr ""
 
-#: handler.py:107
+#: __init__.py:290
 msgid "Local branch up to date"
 msgstr ""
 
-#: handler.py:108
+#: __init__.py:291
 msgid "There are no missing revisions."
 msgstr ""
 
-#: handler.py:132
+#: __init__.py:301
 msgid "Pulling is not possible until there is a parent location."
 msgstr ""
 
-#: handler.py:150
+#: __init__.py:316
 msgid "Pull successful"
 msgstr ""
 
-#: handler.py:151
+#: __init__.py:316
 #, python-format
 msgid "%d revision(s) pulled."
 msgstr ""
 
-#: handler.py:193
-msgid "Directory is already a branch"
-msgstr ""
-
-#: handler.py:194
-#, python-format
-msgid ""
-"The current directory (%s) is already a branch.\n"
-"You can start using it, or initialize another directory."
-msgstr ""
-
-#: handler.py:196
-msgid "Branch without a working tree"
-msgstr ""
-
-#: handler.py:197
-#, python-format
-msgid ""
-"The current directory (%s)\n"
-"is a branch without a working tree."
-msgstr ""
-
-#: handler.py:199
+#: __init__.py:330 menu.py:205
+msgid "Conflicts detected"
+msgstr ""
+
+#: __init__.py:331 menu.py:206
+msgid "Please have a look at the working tree before continuing."
+msgstr ""
+
+#: __init__.py:333 menu.py:208
+msgid "Revert successful"
+msgstr ""
+
+#: __init__.py:334 menu.py:209
+msgid "All files reverted to last revision."
+msgstr ""
+
+#: __init__.py:364
 msgid "Initialize successful"
 msgstr ""
 
-#: handler.py:200
+#: __init__.py:365
 msgid "Directory successfully initialized."
 msgstr ""
 
-#: handler.py:347
-msgid "We feel sorry"
-msgstr ""
-
-#: handler.py:348
-msgid "This feature is not yet implemented."
-msgstr ""
-
-#: menu.py:50
+#: __init__.py:560 __init__.py:767
+msgid "Bookmarks"
+msgstr ""
+
+#: __init__.py:567 menu.py:85
+msgid "Bookmark"
+msgstr ""
+
+#: __init__.py:671 __init__.py:867
+msgid "unchanged"
+msgstr ""
+
+#: __init__.py:673 __init__.py:869
+msgid "ignored"
+msgstr ""
+
+#: __init__.py:675 __init__.py:871
+msgid "unknown"
+msgstr ""
+
+#: __init__.py:680
+msgid "Filename"
+msgstr ""
+
+#: __init__.py:681
+msgid "Status"
+msgstr ""
+
+#: add.py:68 menu.py:149 menu.py:163 menu.py:185 remove.py:68 remove.py:130
+msgid ""
+"Please select a file from the list,\n"
+"or choose the other option."
+msgstr ""
+
+#: bookmark.py:46
+msgid "Title:"
+msgstr ""
+
+#: bookmark.py:81
+msgid "No title given"
+msgstr ""
+
+#: bookmark.py:82
+msgid "Please specify a title to continue."
+msgstr ""
+
+#: guifiles.py:35
+msgid "Glade file cannot be found."
+msgstr ""
+
+#: guifiles.py:51
 msgid "UI description file cannot be found."
 msgstr ""
 
-#: menu.py:62
+#: menu.py:57
 msgid "Add"
 msgstr ""
 
-#: menu.py:63
+#: menu.py:58
 msgid "Add the selected file"
 msgstr ""
 
-#: menu.py:66 menu.py:90
+#: menu.py:61 menu.py:93
 msgid "Remove"
 msgstr ""
 
-#: menu.py:67
+#: menu.py:62
 msgid "Remove the selected file"
 msgstr ""
 
+#: menu.py:65
+msgid "Rename"
+msgstr ""
+
+#: menu.py:66
+msgid "Rename the selected file"
+msgstr ""
+
+#: menu.py:69
+msgid "Open"
+msgstr ""
+
 #: menu.py:70
-msgid "Open"
-msgstr ""
-
-#: menu.py:71
 msgid "Open the selected file"
 msgstr ""
 
-#: menu.py:75
+#: menu.py:73
+msgid "Revert"
+msgstr ""
+
+#: menu.py:74
+msgid "Revert the changes"
+msgstr ""
+
+#: menu.py:78
 msgid "Commit the changes"
 msgstr ""
 
-#: menu.py:79
+#: menu.py:81
+msgid "Diff"
+msgstr ""
+
+#: menu.py:82
 msgid "Show the diff of the file"
 msgstr ""
 
-#: menu.py:82
-msgid "Bookmark"
-msgstr ""
-
-#: menu.py:83
+#: menu.py:86
 msgid "Bookmark current location"
 msgstr ""
 
-#: menu.py:86
+#: menu.py:89
 msgid "Edit"
 msgstr ""
 
-#: menu.py:87
+#: menu.py:90
 msgid "Edit the selected bookmark"
 msgstr ""
 
-#: menu.py:91
+#: menu.py:94
 msgid "Remove the selected bookmark"
 msgstr ""
 
-#: menu.py:94
+#: menu.py:97
 msgid "Open Folder"
 msgstr ""
 
-#: menu.py:95
+#: menu.py:98
 msgid "Open bookmark folder in Nautilus"
 msgstr ""
 
-#: menu.py:98
+#: menu.py:101
 msgid "Selected..."
 msgstr ""
 
-#: menu.py:99
+#: menu.py:102
 msgid "Show the differences of the selected file"
 msgstr ""
 
-#: menu.py:102
+#: menu.py:105
 msgid "All..."
 msgstr ""
 
-#: menu.py:103
+#: menu.py:106
 msgid "Show the differences of all files"
 msgstr ""
 
-#: menu.py:174 remove.py:83
-msgid "File not versioned"
-msgstr ""
-
-#: menu.py:175 remove.py:84
-msgid "The selected file is not versioned."
-msgstr ""
-
-#: menu.py:219
+#: menu.py:245
 msgid "Bookmark successfully added"
 msgstr ""
 
-#: menu.py:220
+#: menu.py:246
 msgid ""
 "The current directory was bookmarked. You can reach\n"
 "it by selecting it from the left panel."
 msgstr ""
 
-#: menu.py:222
+#: menu.py:249
 msgid "Location already bookmarked"
 msgstr ""
 
-#: menu.py:223
+#: menu.py:250
 msgid ""
 "The current directory is already bookmarked.\n"
 "See the left panel for reference."
 msgstr ""
 
-#: mkdir.py:66
+#: mkdir.py:67
 msgid "No directory name given"
 msgstr ""
 
-#: mkdir.py:67
+#: mkdir.py:68
 msgid "Please specify a desired name for the new directory."
 msgstr ""
 
-#: mkdir.py:83 mkdir.py:96
+#: mkdir.py:79 mkdir.py:89
 msgid "Directory already exists"
 msgstr ""
 
-#: mkdir.py:84 mkdir.py:97
+#: mkdir.py:80 mkdir.py:90
 msgid "Please specify another name to continue."
 msgstr ""
 
-#: mkdir.py:88
-msgid "Directory is not in a branch"
-msgstr ""
-
-#: mkdir.py:89
-msgid "You can only create a non-versioned directory."
-msgstr ""
-
-#: move.py:69 rename.py:67
+#: move.py:80 rename.py:70
 msgid "Please select a file from the list to proceed."
 msgstr ""
 
-#: move.py:79 rename.py:84
+#: move.py:89 rename.py:86
 msgid "Not the same branch"
 msgstr ""
 
-#: move.py:80 rename.py:85
+#: move.py:90 rename.py:87
 msgid "The destination is not in the same branch."
 msgstr ""
 
-#: move.py:85 rename.py:89
-msgid "File is not in a branch"
-msgstr ""
-
-#: move.py:86 rename.py:90
-msgid "The selected file is not in a branch."
-msgstr ""
-
-#: push.py:131
-msgid "Push location is unknown"
-msgstr ""
-
-#: push.py:132
-msgid "Please specify a location manually."
-msgstr ""
-
-#: push.py:139 push.py:167
-msgid "Branches have been diverged"
-msgstr ""
-
-#: push.py:140 push.py:168
-msgid ""
-"You cannot push if branches have diverged. Use the\n"
-"overwrite option if you want to push anyway."
-msgstr ""
-
-#: push.py:147
-msgid "No location specified"
-msgstr ""
-
-#: push.py:148
-msgid "Please specify a location or use the default."
-msgstr ""
-
-#: push.py:172
-msgid "Path prefix not created"
-msgstr ""
-
-#: push.py:173
-msgid ""
-"The path leading up to the specified location couldn't\n"
-"be created."
-msgstr ""
-
-#: push.py:183
-msgid "Push successful"
-msgstr ""
-
-#: push.py:184
-#, python-format
-msgid "%d revision(s) pushed."
-msgstr ""
-
-#: push.py:202
-msgid "<b>Write access is probably available</b>"
-msgstr ""
-
-#: push.py:206
-msgid "<b>No write access</b>"
-msgstr ""
-
-#: push.py:210
-msgid "<b>Could not determine</b>"
-msgstr ""
-
-#: remove.py:100
+#: remove.py:79 remove.py:139
 msgid "No matching files"
 msgstr ""
 
-#: remove.py:101
+#: remove.py:80 remove.py:140
 msgid "No added files were found in the working tree."
 msgstr ""
 
-#: rename.py:71
+#: remove.py:105
+msgid "Which file(s) do you want to remove?"
+msgstr ""
+
+#: remove.py:106
+msgid "Selected only"
+msgstr ""
+
+#: remove.py:107
+msgid "All files with status 'added'"
+msgstr ""
+
+#: remove.py:108
+msgid "_Remove"
+msgstr ""
+
+#: rename.py:74
 msgid "Filename not given"
 msgstr ""
 
-#: rename.py:72
+#: rename.py:75
 msgid "Please specify a new name for the file."
 msgstr ""
-
-#: status.py:137
-msgid "Unknown"
-msgstr ""
-
-#: status.py:142
-msgid "No changes."
-msgstr ""

=== modified file 'setup.py'
--- setup.py	2007-01-30 17:26:34 +0000
+++ setup.py	2007-03-02 16:02:56 +0000
@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/python
 """GTK+ Frontends for various Bazaar commands."""
 
 from distutils.core import setup
@@ -10,41 +10,55 @@
 import sys
 
 class InstallData(install_data):
-	def run(self):
-		self.data_files.extend(self._compile_po_files())
-		install_data.run(self)
-
-	def _compile_po_files(self):
-		data_files = []
-		
-		# Don't install language files on Win32
-		if sys.platform == 'win32':
-		    return data_files
-		
-		PO_DIR = 'po'
-		for po in glob.glob(os.path.join(PO_DIR,'*.po')):
-			lang = os.path.basename(po[:-3])
-			# It's necessary to compile in this directory (not in po_dir)
-			# because install_data can't rename file
-			mo = os.path.join('build', 'mo', lang, 'olive-gtk.mo')
-			
-			directory = os.path.dirname(mo)
-			if not os.path.exists(directory):
-				info('creating %s' % directory)
-				os.makedirs(directory)
-			
-			if newer(po, mo):
-				# True if mo doesn't exist
-				cmd = 'msgfmt -o %s %s' % (mo, po)
-				info('compiling %s -> %s' % (po, mo))
-				if os.system(cmd) != 0:
-					raise SystemExit('Error while running msgfmt')
-
-				dest = os.path.dirname(os.path.join('share', 'locale', lang, 'LC_MESSAGES', 'olive-gtk.mo'))
-				data_files.append((dest, [mo]))
-		
-		return data_files
-
+    def run(self):
+        self.data_files.extend(self._compile_po_files())
+        # Disable for now - performance issues
+        #self.data_files.extend(self._nautilus_plugin())
+        install_data.run(self)
+    
+    def _compile_po_files(self):
+        data_files = []
+        
+        # Don't install language files on Win32
+        if sys.platform == 'win32':
+            return data_files
+        
+        PO_DIR = 'po'
+        for po in glob.glob(os.path.join(PO_DIR,'*.po')):
+            lang = os.path.basename(po[:-3])
+            # It's necessary to compile in this directory (not in po_dir)
+            # because install_data can't rename file
+            mo = os.path.join('build', 'mo', lang, 'olive-gtk.mo')
+            
+            directory = os.path.dirname(mo)
+            if not os.path.exists(directory):
+                info('creating %s' % directory)
+                os.makedirs(directory)
+            
+            if newer(po, mo):
+                # True if mo doesn't exist
+                cmd = 'msgfmt -o %s %s' % (mo, po)
+                info('compiling %s -> %s' % (po, mo))
+                if os.system(cmd) != 0:
+                    raise SystemExit('Error while running msgfmt')
+                
+                dest = os.path.dirname(os.path.join('share', 'locale', lang, 'LC_MESSAGES', 'olive-gtk.mo'))
+                data_files.append((dest, [mo]))
+        
+        return data_files
+    
+    def _nautilus_plugin(self):
+        files = []
+        if sys.platform[:5] == 'linux':
+            cmd = os.popen('pkg-config --variable=pythondir nautilus-python', 'r')
+            res = cmd.readline()
+            ret = cmd.close()
+            
+            if ret is None:
+                dest = res[5:]
+                files.append((dest, ['nautilus-bzr.py']))
+        
+        return files
 
 
 setup(
@@ -59,14 +73,16 @@
         "bzrlib.plugins.gtk": ".",
         "bzrlib.plugins.gtk.viz": "viz", 
         "bzrlib.plugins.gtk.annotate": "annotate",
-        "bzrlib.plugins.gtk.olive": "olive"
+        "bzrlib.plugins.gtk.olive": "olive",
+        "bzrlib.plugins.gtk.tests": "tests"
         },
     packages = [
 		"olive",
         "bzrlib.plugins.gtk",
         "bzrlib.plugins.gtk.viz",
         "bzrlib.plugins.gtk.annotate",
-        "bzrlib.plugins.gtk.olive"
+        "bzrlib.plugins.gtk.olive",
+        "bzrlib.plugins.gtk.tests"
         ],
       data_files=[('share/olive', ['olive.glade',
                                    'oliveicon2.png',

=== modified file 'status.py'
--- status.py	2007-02-03 16:03:23 +0000
+++ status.py	2007-02-03 17:01:18 +0000
@@ -39,8 +39,11 @@
 
     def _create(self):
         self.set_default_size(400, 300)
+        scrolledwindow = gtk.ScrolledWindow()
+        scrolledwindow.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
         self.treeview = gtk.TreeView()
-        self.vbox.pack_start(self.treeview, True, True)
+        scrolledwindow.add(self.treeview)
+        self.vbox.pack_start(scrolledwindow, True, True)
         self.vbox.show_all()
 
     def row_diff(self, tv, path, tvc):

